
#line 1 "../../../src/angel/angel_config_parser.rl"
#include <lighttpd/angel_base.h>
#include <lighttpd/angel_config_parser.h>

typedef struct {
	GArray *g_stack;
	int *stack;
	int cs, top;

	/* readingtoken signals that the parser is reading a token; in case
	 * the data cames in chunks, the parse function has to append the
	 * data to the token and handle tokenstart in the next chunk
	 */
	GString *token;
	gboolean readingtoken;

	char hexchar;
	gint64 number, number2;
	gboolean negate; /* sign for parsing numbers */

	/* item */
	GString *itemname;
	liValue *itemvalue;

	/* every time a collection gets parsed, the collection is pushed on the stack.
	 * in some other cases a LI_VALUE_STRING gets pushed (the key in hashes for example)
	 * while a second value gets parsed.
	 */
	GPtrArray *valuestack;
	liValue *curvalue;

	/* temporary buffer to format a character for logging */
	gchar buf[8];
} pcontext;

typedef struct {
	const gchar *filename;
	int line, column;
} filecontext;

GQuark li_angel_config_parser_error_quark() {
	return g_quark_from_static_string("angel-config-parser-error-quark");
}

static gchar *format_char(pcontext *ctx, gchar c) {
	if (g_ascii_isprint(c)) {
		ctx->buf[0] = c;
		ctx->buf[1] = '\0';
	} else switch (c) {
	case '\n': ctx->buf[0] = '\\'; ctx->buf[1] = 'n'; ctx->buf[2] = '\0'; break;
	case '\r': ctx->buf[0] = '\\'; ctx->buf[1] = 'r'; ctx->buf[2] = '\0'; break;
	case '\t': ctx->buf[0] = '\\'; ctx->buf[1] = 't'; ctx->buf[2] = '\0'; break;
	default: g_snprintf(ctx->buf, 8, "\\x%02X", (unsigned int) (unsigned char) c); break;
	}
	return ctx->buf;
}

#define PARSE_ERROR_FMT(fmt, ...) do { \
	g_set_error(err, \
		LI_ANGEL_CONFIG_PARSER_ERROR, \
		LI_ANGEL_CONFIG_PARSER_ERROR_PARSE, \
		"Parsing failed in '%s:%i,%i': " fmt, \
		fctx->filename, fctx->line, fctx->column, \
		__VA_ARGS__); \
} while (0)

#define PARSE_ERROR(msg) PARSE_ERROR_FMT("%s", msg)

#define UPDATE_COLUMN() do { \
	fctx->column += p - linestart; \
	linestart = p; \
} while (0)


#line 369 "../../../src/angel/angel_config_parser.rl"



#line 81 "angel_config_parser.c"
static const short _angel_config_parser_key_offsets[] = {
	0, 0, 2, 19, 27, 35, 37, 48, 
	59, 61, 80, 101, 122, 127, 134, 141, 
	143, 150, 156, 162, 164, 166, 176, 184, 
	192, 194, 203, 212, 214, 216, 225, 227, 
	229, 231, 233, 235, 237, 239, 246, 248, 
	250, 252, 254, 256, 258, 265, 267, 269, 
	271, 273, 275, 277, 279, 300, 321, 326, 
	334, 342, 350, 352, 359, 365, 371, 373, 
	375, 386, 395, 404, 406, 415, 424, 426, 
	428, 438, 440, 442, 444, 446, 448, 450, 
	452, 460, 462, 464, 466, 468, 470, 472, 
	480, 482, 484, 486, 488, 490, 492, 494, 
	502, 510, 515, 522, 529, 536, 538, 558, 
	578, 583, 591, 599, 607, 609, 616, 622, 
	628, 630, 632, 643, 652, 661, 663, 672, 
	681, 683, 685, 695, 697, 699, 701, 703, 
	705, 707, 709, 717, 719, 721, 723, 725, 
	727, 729, 737, 739, 741, 743, 745, 747, 
	749, 751, 758, 764, 770, 772, 782, 792, 
	792
};

static const char _angel_config_parser_trans_keys[] = {
	10, 13, 10, 13, 32, 35, 59, 95, 
	123, 9, 12, 45, 46, 48, 57, 65, 
	90, 97, 122, 10, 13, 32, 35, 59, 
	123, 9, 12, 10, 13, 32, 35, 59, 
	123, 9, 12, 10, 13, 10, 13, 32, 
	35, 125, 9, 12, 65, 90, 97, 122, 
	10, 13, 32, 35, 125, 9, 12, 65, 
	90, 97, 122, 10, 13, 10, 13, 32, 
	34, 35, 40, 59, 91, 95, 9, 12, 
	45, 46, 48, 57, 65, 90, 97, 122, 
	10, 13, 32, 34, 35, 40, 45, 59, 
	68, 69, 70, 84, 91, 100, 101, 102, 
	116, 9, 12, 48, 57, 10, 13, 32, 
	34, 35, 40, 45, 59, 68, 69, 70, 
	84, 91, 100, 101, 102, 116, 9, 12, 
	48, 57, 34, 92, 127, 0, 31, 10, 
	13, 32, 35, 59, 9, 12, 10, 13, 
	32, 35, 59, 9, 12, 10, 13, 110, 
	114, 116, 120, 127, 0, 31, 48, 57, 
	65, 70, 97, 102, 48, 57, 65, 70, 
	97, 102, 10, 13, 48, 57, 10, 13, 
	32, 35, 45, 59, 9, 12, 48, 57, 
	10, 13, 32, 35, 45, 59, 9, 12, 
	10, 13, 32, 35, 45, 59, 9, 12, 
	10, 13, 10, 13, 32, 35, 45, 9, 
	12, 48, 57, 10, 13, 32, 35, 45, 
	9, 12, 48, 57, 10, 13, 48, 57, 
	10, 13, 32, 35, 59, 9, 12, 48, 
	57, 73, 105, 83, 115, 65, 97, 66, 
	98, 76, 108, 69, 101, 68, 100, 10, 
	13, 32, 35, 59, 9, 12, 78, 110, 
	65, 97, 66, 98, 76, 108, 69, 101, 
	68, 100, 10, 13, 32, 35, 59, 9, 
	12, 65, 97, 76, 108, 83, 115, 69, 
	101, 82, 114, 85, 117, 69, 101, 10, 
	13, 32, 34, 35, 40, 41, 45, 68, 
	69, 70, 84, 91, 100, 101, 102, 116, 
	9, 12, 48, 57, 10, 13, 32, 34, 
	35, 40, 41, 45, 68, 69, 70, 84, 
	91, 100, 101, 102, 116, 9, 12, 48, 
	57, 34, 92, 127, 0, 31, 10, 13, 
	32, 35, 41, 44, 9, 12, 10, 13, 
	32, 35, 41, 44, 9, 12, 10, 13, 
	32, 35, 41, 44, 9, 12, 10, 13, 
	110, 114, 116, 120, 127, 0, 31, 48, 
	57, 65, 70, 97, 102, 48, 57, 65, 
	70, 97, 102, 10, 13, 48, 57, 10, 
	13, 32, 35, 41, 44, 45, 9, 12, 
	48, 57, 10, 13, 32, 35, 41, 44, 
	45, 9, 12, 10, 13, 32, 35, 41, 
	44, 45, 9, 12, 10, 13, 10, 13, 
	32, 35, 45, 9, 12, 48, 57, 10, 
	13, 32, 35, 45, 9, 12, 48, 57, 
	10, 13, 48, 57, 10, 13, 32, 35, 
	41, 44, 9, 12, 48, 57, 73, 105, 
	83, 115, 65, 97, 66, 98, 76, 108, 
	69, 101, 68, 100, 10, 13, 32, 35, 
	41, 44, 9, 12, 78, 110, 65, 97, 
	66, 98, 76, 108, 69, 101, 68, 100, 
	10, 13, 32, 35, 41, 44, 9, 12, 
	65, 97, 76, 108, 83, 115, 69, 101, 
	82, 114, 85, 117, 69, 101, 10, 13, 
	32, 34, 35, 93, 9, 12, 10, 13, 
	32, 34, 35, 93, 9, 12, 34, 92, 
	127, 0, 31, 10, 13, 32, 35, 58, 
	9, 12, 10, 13, 32, 35, 58, 9, 
	12, 10, 13, 32, 35, 58, 9, 12, 
	10, 13, 10, 13, 32, 34, 35, 40, 
	45, 68, 69, 70, 84, 91, 100, 101, 
	102, 116, 9, 12, 48, 57, 10, 13, 
	32, 34, 35, 40, 45, 68, 69, 70, 
	84, 91, 100, 101, 102, 116, 9, 12, 
	48, 57, 34, 92, 127, 0, 31, 10, 
	13, 32, 35, 44, 93, 9, 12, 10, 
	13, 32, 35, 44, 93, 9, 12, 10, 
	13, 32, 35, 44, 93, 9, 12, 10, 
	13, 110, 114, 116, 120, 127, 0, 31, 
	48, 57, 65, 70, 97, 102, 48, 57, 
	65, 70, 97, 102, 10, 13, 48, 57, 
	10, 13, 32, 35, 44, 45, 93, 9, 
	12, 48, 57, 10, 13, 32, 35, 44, 
	45, 93, 9, 12, 10, 13, 32, 35, 
	44, 45, 93, 9, 12, 10, 13, 10, 
	13, 32, 35, 45, 9, 12, 48, 57, 
	10, 13, 32, 35, 45, 9, 12, 48, 
	57, 10, 13, 48, 57, 10, 13, 32, 
	35, 44, 93, 9, 12, 48, 57, 73, 
	105, 83, 115, 65, 97, 66, 98, 76, 
	108, 69, 101, 68, 100, 10, 13, 32, 
	35, 44, 93, 9, 12, 78, 110, 65, 
	97, 66, 98, 76, 108, 69, 101, 68, 
	100, 10, 13, 32, 35, 44, 93, 9, 
	12, 65, 97, 76, 108, 83, 115, 69, 
	101, 82, 114, 85, 117, 69, 101, 110, 
	114, 116, 120, 127, 0, 31, 48, 57, 
	65, 70, 97, 102, 48, 57, 65, 70, 
	97, 102, 10, 13, 10, 13, 32, 35, 
	9, 12, 65, 90, 97, 122, 10, 13, 
	32, 35, 9, 12, 65, 90, 97, 122, 
	0
};

static const char _angel_config_parser_single_lengths[] = {
	0, 2, 7, 6, 6, 2, 5, 5, 
	2, 9, 17, 17, 3, 5, 5, 2, 
	5, 0, 0, 2, 0, 6, 6, 6, 
	2, 5, 5, 2, 0, 5, 2, 2, 
	2, 2, 2, 2, 2, 5, 2, 2, 
	2, 2, 2, 2, 5, 2, 2, 2, 
	2, 2, 2, 2, 17, 17, 3, 6, 
	6, 6, 2, 5, 0, 0, 2, 0, 
	7, 7, 7, 2, 5, 5, 2, 0, 
	6, 2, 2, 2, 2, 2, 2, 2, 
	6, 2, 2, 2, 2, 2, 2, 6, 
	2, 2, 2, 2, 2, 2, 2, 6, 
	6, 3, 5, 5, 5, 2, 16, 16, 
	3, 6, 6, 6, 2, 5, 0, 0, 
	2, 0, 7, 7, 7, 2, 5, 5, 
	2, 0, 6, 2, 2, 2, 2, 2, 
	2, 2, 6, 2, 2, 2, 2, 2, 
	2, 6, 2, 2, 2, 2, 2, 2, 
	2, 5, 0, 0, 2, 4, 4, 0, 
	0
};

static const char _angel_config_parser_range_lengths[] = {
	0, 0, 5, 1, 1, 0, 3, 3, 
	0, 5, 2, 2, 1, 1, 1, 0, 
	1, 3, 3, 0, 1, 2, 1, 1, 
	0, 2, 2, 0, 1, 2, 0, 0, 
	0, 0, 0, 0, 0, 1, 0, 0, 
	0, 0, 0, 0, 1, 0, 0, 0, 
	0, 0, 0, 0, 2, 2, 1, 1, 
	1, 1, 0, 1, 3, 3, 0, 1, 
	2, 1, 1, 0, 2, 2, 0, 1, 
	2, 0, 0, 0, 0, 0, 0, 0, 
	1, 0, 0, 0, 0, 0, 0, 1, 
	0, 0, 0, 0, 0, 0, 0, 1, 
	1, 1, 1, 1, 1, 0, 2, 2, 
	1, 1, 1, 1, 0, 1, 3, 3, 
	0, 1, 2, 1, 1, 0, 2, 2, 
	0, 1, 2, 0, 0, 0, 0, 0, 
	0, 0, 1, 0, 0, 0, 0, 0, 
	0, 1, 0, 0, 0, 0, 0, 0, 
	0, 1, 3, 3, 0, 3, 3, 0, 
	0
};

static const short _angel_config_parser_index_offsets[] = {
	0, 0, 3, 16, 24, 32, 35, 44, 
	53, 56, 71, 91, 111, 116, 123, 130, 
	133, 140, 144, 148, 151, 153, 162, 170, 
	178, 181, 189, 197, 200, 202, 210, 213, 
	216, 219, 222, 225, 228, 231, 238, 241, 
	244, 247, 250, 253, 256, 263, 266, 269, 
	272, 275, 278, 281, 284, 304, 324, 329, 
	337, 345, 353, 356, 363, 367, 371, 374, 
	376, 386, 395, 404, 407, 415, 423, 426, 
	428, 437, 440, 443, 446, 449, 452, 455, 
	458, 466, 469, 472, 475, 478, 481, 484, 
	492, 495, 498, 501, 504, 507, 510, 513, 
	521, 529, 534, 541, 548, 555, 558, 577, 
	596, 601, 609, 617, 625, 628, 635, 639, 
	643, 646, 648, 658, 667, 676, 679, 687, 
	695, 698, 700, 709, 712, 715, 718, 721, 
	724, 727, 730, 738, 741, 744, 747, 750, 
	753, 756, 764, 767, 770, 773, 776, 779, 
	782, 785, 792, 796, 800, 803, 811, 819, 
	820
};

static const unsigned char _angel_config_parser_trans_targs[] = {
	149, 150, 1, 3, 4, 3, 5, 149, 
	2, 6, 3, 2, 2, 2, 2, 0, 
	3, 4, 3, 5, 149, 6, 3, 0, 
	3, 4, 3, 5, 149, 6, 3, 0, 
	3, 4, 5, 6, 7, 6, 8, 149, 
	6, 9, 9, 0, 6, 7, 6, 8, 
	149, 6, 9, 9, 0, 6, 7, 8, 
	10, 11, 10, 12, 19, 13, 6, 13, 
	9, 10, 9, 9, 9, 9, 0, 10, 
	11, 10, 12, 19, 13, 20, 6, 30, 
	38, 45, 49, 13, 30, 38, 45, 49, 
	10, 21, 0, 10, 11, 10, 12, 19, 
	13, 20, 6, 30, 38, 45, 49, 13, 
	30, 38, 45, 49, 10, 21, 0, 13, 
	16, 0, 0, 12, 13, 14, 13, 15, 
	6, 13, 0, 13, 14, 13, 15, 6, 
	13, 0, 13, 14, 15, 12, 12, 12, 
	17, 0, 0, 12, 18, 18, 18, 0, 
	12, 12, 12, 0, 10, 11, 19, 21, 
	0, 22, 23, 22, 24, 25, 6, 22, 
	21, 0, 22, 23, 22, 24, 25, 6, 
	22, 0, 22, 23, 22, 24, 25, 6, 
	22, 0, 22, 23, 24, 25, 26, 25, 
	27, 28, 25, 29, 0, 25, 26, 25, 
	27, 28, 25, 29, 0, 25, 26, 27, 
	29, 0, 13, 14, 13, 15, 6, 13, 
	29, 0, 31, 31, 0, 32, 32, 0, 
	33, 33, 0, 34, 34, 0, 35, 35, 
	0, 36, 36, 0, 37, 37, 0, 13, 
	14, 13, 15, 6, 13, 0, 39, 39, 
	0, 40, 40, 0, 41, 41, 0, 42, 
	42, 0, 43, 43, 0, 44, 44, 0, 
	13, 14, 13, 15, 6, 13, 0, 46, 
	46, 0, 47, 47, 0, 48, 48, 0, 
	37, 37, 0, 50, 50, 0, 51, 51, 
	0, 44, 44, 0, 52, 53, 52, 54, 
	62, 55, 151, 63, 73, 81, 88, 92, 
	55, 73, 81, 88, 92, 52, 64, 0, 
	52, 53, 52, 54, 62, 55, 151, 63, 
	73, 81, 88, 92, 55, 73, 81, 88, 
	92, 52, 64, 0, 55, 59, 0, 0, 
	54, 56, 57, 56, 58, 151, 52, 56, 
	0, 56, 57, 56, 58, 151, 52, 56, 
	0, 56, 57, 56, 58, 151, 52, 56, 
	0, 56, 57, 58, 54, 54, 54, 60, 
	0, 0, 54, 61, 61, 61, 0, 54, 
	54, 54, 0, 52, 53, 62, 64, 0, 
	65, 66, 65, 67, 151, 52, 68, 65, 
	64, 0, 65, 66, 65, 67, 151, 52, 
	68, 65, 0, 65, 66, 65, 67, 151, 
	52, 68, 65, 0, 65, 66, 67, 68, 
	69, 68, 70, 71, 68, 72, 0, 68, 
	69, 68, 70, 71, 68, 72, 0, 68, 
	69, 70, 72, 0, 56, 57, 56, 58, 
	151, 52, 56, 72, 0, 74, 74, 0, 
	75, 75, 0, 76, 76, 0, 77, 77, 
	0, 78, 78, 0, 79, 79, 0, 80, 
	80, 0, 56, 57, 56, 58, 151, 52, 
	56, 0, 82, 82, 0, 83, 83, 0, 
	84, 84, 0, 85, 85, 0, 86, 86, 
	0, 87, 87, 0, 56, 57, 56, 58, 
	151, 52, 56, 0, 89, 89, 0, 90, 
	90, 0, 91, 91, 0, 80, 80, 0, 
	93, 93, 0, 94, 94, 0, 87, 87, 
	0, 95, 96, 95, 97, 148, 152, 95, 
	0, 95, 96, 95, 97, 148, 152, 95, 
	0, 98, 145, 0, 0, 97, 99, 100, 
	99, 101, 102, 99, 0, 99, 100, 99, 
	101, 102, 99, 0, 99, 100, 99, 101, 
	102, 99, 0, 99, 100, 101, 102, 103, 
	102, 104, 112, 105, 113, 123, 131, 138, 
	142, 105, 123, 131, 138, 142, 102, 114, 
	0, 102, 103, 102, 104, 112, 105, 113, 
	123, 131, 138, 142, 105, 123, 131, 138, 
	142, 102, 114, 0, 105, 109, 0, 0, 
	104, 106, 107, 106, 108, 95, 152, 106, 
	0, 106, 107, 106, 108, 95, 152, 106, 
	0, 106, 107, 106, 108, 95, 152, 106, 
	0, 106, 107, 108, 104, 104, 104, 110, 
	0, 0, 104, 111, 111, 111, 0, 104, 
	104, 104, 0, 102, 103, 112, 114, 0, 
	115, 116, 115, 117, 95, 118, 152, 115, 
	114, 0, 115, 116, 115, 117, 95, 118, 
	152, 115, 0, 115, 116, 115, 117, 95, 
	118, 152, 115, 0, 115, 116, 117, 118, 
	119, 118, 120, 121, 118, 122, 0, 118, 
	119, 118, 120, 121, 118, 122, 0, 118, 
	119, 120, 122, 0, 106, 107, 106, 108, 
	95, 152, 106, 122, 0, 124, 124, 0, 
	125, 125, 0, 126, 126, 0, 127, 127, 
	0, 128, 128, 0, 129, 129, 0, 130, 
	130, 0, 106, 107, 106, 108, 95, 152, 
	106, 0, 132, 132, 0, 133, 133, 0, 
	134, 134, 0, 135, 135, 0, 136, 136, 
	0, 137, 137, 0, 106, 107, 106, 108, 
	95, 152, 106, 0, 139, 139, 0, 140, 
	140, 0, 141, 141, 0, 130, 130, 0, 
	143, 143, 0, 144, 144, 0, 137, 137, 
	0, 97, 97, 97, 146, 0, 0, 97, 
	147, 147, 147, 0, 97, 97, 97, 0, 
	95, 96, 148, 149, 150, 149, 1, 149, 
	2, 2, 0, 149, 150, 149, 1, 149, 
	2, 2, 0, 0, 0, 0
};

static const char _angel_config_parser_trans_actions[] = {
	2, 2, 0, 5, 5, 4, 4, 6, 
	0, 4, 4, 0, 0, 0, 0, 3, 
	2, 2, 0, 0, 7, 0, 0, 3, 
	8, 2, 0, 0, 7, 0, 0, 3, 
	2, 2, 0, 2, 2, 0, 0, 7, 
	0, 10, 10, 9, 8, 2, 0, 0, 
	7, 0, 10, 10, 9, 2, 2, 0, 
	13, 13, 12, 14, 12, 15, 16, 17, 
	0, 12, 0, 0, 0, 0, 11, 2, 
	2, 0, 18, 0, 19, 20, 22, 0, 
	0, 0, 0, 23, 0, 0, 0, 0, 
	0, 21, 11, 8, 2, 0, 18, 0, 
	19, 20, 22, 0, 0, 0, 0, 23, 
	0, 0, 0, 0, 0, 21, 11, 26, 
	0, 24, 24, 25, 2, 2, 0, 0, 
	22, 0, 27, 8, 2, 0, 0, 22, 
	0, 27, 2, 2, 0, 28, 29, 30, 
	0, 24, 24, 25, 32, 32, 32, 31, 
	33, 33, 33, 31, 2, 2, 0, 35, 
	34, 37, 37, 36, 36, 38, 39, 36, 
	35, 27, 2, 2, 0, 0, 38, 39, 
	0, 27, 8, 2, 0, 0, 38, 39, 
	0, 27, 2, 2, 0, 2, 2, 0, 
	0, 20, 0, 21, 40, 8, 2, 0, 
	0, 20, 0, 21, 40, 2, 2, 0, 
	35, 34, 42, 42, 41, 41, 43, 41, 
	35, 27, 0, 0, 34, 0, 0, 34, 
	0, 0, 34, 0, 0, 34, 0, 0, 
	34, 0, 0, 34, 0, 0, 34, 45, 
	45, 44, 44, 46, 44, 27, 0, 0, 
	34, 0, 0, 34, 0, 0, 34, 0, 
	0, 34, 0, 0, 34, 0, 0, 34, 
	48, 48, 47, 47, 49, 47, 27, 0, 
	0, 34, 0, 0, 34, 0, 0, 34, 
	0, 0, 34, 0, 0, 34, 0, 0, 
	34, 0, 0, 34, 2, 2, 0, 18, 
	0, 19, 51, 20, 0, 0, 0, 0, 
	23, 0, 0, 0, 0, 0, 21, 50, 
	8, 2, 0, 18, 0, 19, 51, 20, 
	0, 0, 0, 0, 23, 0, 0, 0, 
	0, 0, 21, 50, 26, 0, 24, 24, 
	25, 54, 54, 53, 53, 55, 53, 53, 
	52, 2, 2, 0, 0, 51, 0, 0, 
	52, 8, 2, 0, 0, 51, 0, 0, 
	52, 2, 2, 0, 28, 29, 30, 0, 
	24, 24, 25, 32, 32, 32, 31, 33, 
	33, 33, 31, 2, 2, 0, 35, 34, 
	57, 57, 56, 56, 58, 56, 38, 56, 
	35, 52, 2, 2, 0, 0, 58, 56, 
	38, 0, 52, 8, 2, 0, 0, 58, 
	56, 38, 0, 52, 2, 2, 0, 2, 
	2, 0, 0, 20, 0, 21, 40, 8, 
	2, 0, 0, 20, 0, 21, 40, 2, 
	2, 0, 35, 34, 60, 60, 59, 59, 
	61, 59, 59, 35, 52, 0, 0, 34, 
	0, 0, 34, 0, 0, 34, 0, 0, 
	34, 0, 0, 34, 0, 0, 34, 0, 
	0, 34, 63, 63, 62, 62, 64, 62, 
	62, 52, 0, 0, 34, 0, 0, 34, 
	0, 0, 34, 0, 0, 34, 0, 0, 
	34, 0, 0, 34, 66, 66, 65, 65, 
	67, 65, 65, 52, 0, 0, 34, 0, 
	0, 34, 0, 0, 34, 0, 0, 34, 
	0, 0, 34, 0, 0, 34, 0, 0, 
	34, 2, 2, 0, 18, 0, 69, 0, 
	68, 8, 2, 0, 18, 0, 69, 0, 
	68, 26, 0, 70, 70, 25, 73, 73, 
	72, 72, 72, 72, 71, 2, 2, 0, 
	0, 0, 0, 74, 8, 2, 0, 0, 
	0, 0, 74, 2, 2, 0, 2, 2, 
	0, 18, 0, 19, 20, 0, 0, 0, 
	0, 23, 0, 0, 0, 0, 0, 21, 
	34, 8, 2, 0, 18, 0, 19, 20, 
	0, 0, 0, 0, 23, 0, 0, 0, 
	0, 0, 21, 34, 26, 0, 24, 24, 
	25, 77, 77, 76, 76, 76, 78, 76, 
	75, 2, 2, 0, 0, 0, 69, 0, 
	75, 8, 2, 0, 0, 0, 69, 0, 
	75, 2, 2, 0, 28, 29, 30, 0, 
	24, 24, 25, 32, 32, 32, 31, 33, 
	33, 33, 31, 2, 2, 0, 35, 34, 
	80, 80, 79, 79, 79, 38, 81, 79, 
	35, 75, 2, 2, 0, 0, 79, 38, 
	81, 0, 75, 8, 2, 0, 0, 79, 
	38, 81, 0, 75, 2, 2, 0, 2, 
	2, 0, 0, 20, 0, 21, 40, 8, 
	2, 0, 0, 20, 0, 21, 40, 2, 
	2, 0, 35, 34, 84, 84, 83, 83, 
	83, 85, 83, 35, 75, 0, 0, 34, 
	0, 0, 34, 0, 0, 34, 0, 0, 
	34, 0, 0, 34, 0, 0, 34, 0, 
	0, 34, 87, 87, 86, 86, 86, 88, 
	86, 75, 0, 0, 34, 0, 0, 34, 
	0, 0, 34, 0, 0, 34, 0, 0, 
	34, 0, 0, 34, 90, 90, 89, 89, 
	89, 91, 89, 75, 0, 0, 34, 0, 
	0, 34, 0, 0, 34, 0, 0, 34, 
	0, 0, 34, 0, 0, 34, 0, 0, 
	34, 28, 29, 30, 0, 70, 70, 25, 
	32, 32, 32, 92, 33, 33, 33, 92, 
	2, 2, 0, 2, 2, 0, 0, 0, 
	10, 10, 93, 8, 2, 0, 0, 0, 
	10, 10, 93, 0, 0, 0
};

static const char _angel_config_parser_eof_actions[] = {
	0, 1, 3, 3, 3, 1, 9, 9, 
	1, 11, 11, 11, 24, 27, 27, 27, 
	24, 31, 31, 27, 34, 27, 27, 27, 
	11, 40, 40, 40, 34, 27, 34, 34, 
	34, 34, 34, 34, 34, 27, 34, 34, 
	34, 34, 34, 34, 27, 34, 34, 34, 
	34, 34, 34, 34, 50, 50, 24, 52, 
	52, 52, 52, 24, 31, 31, 52, 34, 
	52, 52, 52, 50, 40, 40, 40, 34, 
	52, 34, 34, 34, 34, 34, 34, 34, 
	52, 34, 34, 34, 34, 34, 34, 52, 
	34, 34, 34, 34, 34, 34, 34, 68, 
	68, 70, 71, 74, 74, 74, 34, 34, 
	24, 75, 75, 75, 75, 24, 31, 31, 
	1, 34, 75, 75, 75, 82, 40, 40, 
	40, 34, 75, 34, 34, 34, 34, 34, 
	34, 34, 75, 34, 34, 34, 34, 34, 
	34, 75, 34, 34, 34, 34, 34, 34, 
	34, 70, 92, 92, 75, 0, 0, 0, 
	0
};

static const int angel_config_parser_start = 149;
static const int angel_config_parser_first_final = 149;
static const int angel_config_parser_error = 0;

static const int angel_config_parser_en_value_list_sub = 52;
static const int angel_config_parser_en_value_hash_sub = 95;
static const int angel_config_parser_en_main = 149;


#line 372 "../../../src/angel/angel_config_parser.rl"

static void update_stack(pcontext *ctx) {
	g_array_set_size(ctx->g_stack, ctx->top + 1);
	ctx->stack = (int*) ctx->g_stack->data;
}

static int angel_config_parser_has_error(pcontext *ctx) {
	return ctx->cs == angel_config_parser_error;
}

static int angel_config_parser_is_finished(pcontext *ctx) {
	return ctx->cs >= angel_config_parser_first_final;
}

static pcontext* angel_config_parser_new() {
	pcontext *ctx = g_slice_new0(pcontext);
	ctx->g_stack = g_array_sized_new(FALSE, FALSE, sizeof(int), 8);
	ctx->top = 0;
	g_array_set_size(ctx->g_stack, ctx->top + 1);
	ctx->stack = (int*) ctx->g_stack->data;
	ctx->token = g_string_sized_new(0);
	ctx->valuestack = g_ptr_array_new();

	
#line 546 "angel_config_parser.c"
	{
	 ctx->cs = angel_config_parser_start;
	 ctx->top = 0;
	}

#line 396 "../../../src/angel/angel_config_parser.rl"

	return ctx;
}

static void angel_config_parser_free(pcontext *ctx) {
	if (!ctx) return;

	g_array_free(ctx->g_stack, TRUE);
	g_string_free(ctx->token, TRUE);
	for (guint i = 0; i < ctx->valuestack->len; i++) {
		li_value_free(g_ptr_array_index(ctx->valuestack, i));
	}
	g_ptr_array_free(ctx->valuestack, TRUE);
	if (ctx->itemname) g_string_free(ctx->itemname, TRUE);
	li_value_free(ctx->itemvalue);
	li_value_free(ctx->curvalue);
	g_slice_free(pcontext, ctx);
}

static gboolean angel_config_parser_finalize(pcontext *ctx, filecontext *fctx, GError **err) {
	if (!angel_config_parser_is_finished(ctx)) {
		PARSE_ERROR("unexpected end of file");
		return FALSE;
	}

	return TRUE;
}

static gboolean angel_config_parse_data(liServer *srv, pcontext *ctx, filecontext *fctx, gchar *data, gsize len, GError **err) {
	gchar *p = data, *pe = p+len, *eof = NULL, *linestart = p, *tokenstart = NULL;
	if (ctx->readingtoken) tokenstart = p;

	
#line 586 "angel_config_parser.c"
	{
	int _klen;
	const char *_keys;
	int _trans;

	if ( p == pe )
		goto _test_eof;
	if (  ctx->cs == 0 )
		goto _out;
_resume:
	_keys = _angel_config_parser_trans_keys + _angel_config_parser_key_offsets[ ctx->cs];
	_trans = _angel_config_parser_index_offsets[ ctx->cs];

	_klen = _angel_config_parser_single_lengths[ ctx->cs];
	if ( _klen > 0 ) {
		const char *_lower = _keys;
		const char *_mid;
		const char *_upper = _keys + _klen - 1;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + ((_upper-_lower) >> 1);
			if ( (*p) < *_mid )
				_upper = _mid - 1;
			else if ( (*p) > *_mid )
				_lower = _mid + 1;
			else {
				_trans += (unsigned int)(_mid - _keys);
				goto _match;
			}
		}
		_keys += _klen;
		_trans += _klen;
	}

	_klen = _angel_config_parser_range_lengths[ ctx->cs];
	if ( _klen > 0 ) {
		const char *_lower = _keys;
		const char *_mid;
		const char *_upper = _keys + (_klen<<1) - 2;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + (((_upper-_lower) >> 1) & ~1);
			if ( (*p) < _mid[0] )
				_upper = _mid - 2;
			else if ( (*p) > _mid[1] )
				_lower = _mid + 2;
			else {
				_trans += (unsigned int)((_mid - _keys)>>1);
				goto _match;
			}
		}
		_trans += _klen;
	}

_match:
	 ctx->cs = _angel_config_parser_trans_targs[_trans];

	if ( _angel_config_parser_trans_actions[_trans] == 0 )
		goto _again;

	switch ( _angel_config_parser_trans_actions[_trans] ) {
	case 10:
#line 81 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_truncate(ctx->token, 0);
		tokenstart = p;
		ctx->readingtoken = TRUE;
	}
	break;
	case 2:
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 7:
#line 104 "../../../src/angel/angel_config_parser.rl"
	{
		li_plugins_handle_item(srv, ctx->itemname, ctx->itemvalue);
		g_string_free(ctx->itemname, TRUE);
		ctx->itemname = NULL;
		li_value_free(ctx->itemvalue);
		ctx->itemvalue = NULL;
	}
	break;
	case 93:
#line 124 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected identifier", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 18:
#line 192 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_truncate(ctx->token, 0);
	}
	break;
	case 25:
#line 196 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, p, 1);
	}
	break;
	case 47:
#line 201 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(TRUE);
	}
	break;
	case 44:
#line 205 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(FALSE);
	}
	break;
	case 36:
#line 209 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_number(ctx->number);
	}
	break;
	case 41:
#line 213 "../../../src/angel/angel_config_parser.rl"
	{
		liValueRange vr = { ctx->number2, ctx->number };
		ctx->curvalue = li_value_new_range(vr);
		if (ctx->number2 > ctx->number) {
			GString *tmp = li_value_to_string(ctx->curvalue);
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("range broken: %s (from > to)", tmp->str);
			g_string_free(tmp, TRUE);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
	}
	break;
	case 26:
#line 225 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_string(ctx->token);
		ctx->token = g_string_sized_new(0);
	}
	break;
	case 19:
#line 230 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_list());
		ctx->curvalue = NULL;
		{ update_stack(ctx); { ctx->stack[ ctx->top++] =  ctx->cs;  ctx->cs = 52; goto _again;}}
	}
	break;
	case 53:
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
	break;
	case 51:
#line 240 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 23:
#line 247 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_hash());
		ctx->curvalue = NULL;
		{ update_stack(ctx); { ctx->stack[ ctx->top++] =  ctx->cs;  ctx->cs = 95; goto _again;}}
	}
	break;
	case 72:
#line 252 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, ctx->curvalue);
		ctx->curvalue = NULL;
	}
	break;
	case 76:
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 69:
#line 272 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 22:
#line 284 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (!ctx->curvalue) ctx->curvalue = li_value_new_none();
		if (NULL != g_hash_table_lookup(ctx->itemvalue->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(ctx->itemvalue->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 28:
#line 316 "../../../src/angel/angel_config_parser.rl"
	{ g_string_append(ctx->token, "\n"); }
	break;
	case 30:
#line 317 "../../../src/angel/angel_config_parser.rl"
	{ g_string_append(ctx->token, "\t"); }
	break;
	case 29:
#line 318 "../../../src/angel/angel_config_parser.rl"
	{ g_string_append(ctx->token, "\r"); }
	break;
	case 32:
#line 320 "../../../src/angel/angel_config_parser.rl"
	{ ctx->hexchar  = 16*g_ascii_xdigit_value((*p)); }
	break;
	case 33:
#line 321 "../../../src/angel/angel_config_parser.rl"
	{ ctx->hexchar +=    g_ascii_xdigit_value((*p));
			          g_string_append_len(ctx->token, &ctx->hexchar, 1);
			}
	break;
	case 35:
#line 330 "../../../src/angel/angel_config_parser.rl"
	{
		if (ctx->negate) {
			if ((G_MININT64 + ((*p) - '0')) / 10 > ctx->number) {
				UPDATE_COLUMN();
				PARSE_ERROR("Integer underflow");
				ctx->cs = angel_config_parser_error; {p++; goto _out; }
			}
			ctx->number = ctx->number*10 - ((*p) - '0');
		} else {
			if ((G_MAXINT64 - ((*p) - '0')) / 10 < ctx->number) {
				UPDATE_COLUMN();
				PARSE_ERROR("Integer overflow");
				ctx->cs = angel_config_parser_error; {p++; goto _out; }
			}
			ctx->number = ctx->number*10 + ((*p) - '0');
		}
	}
	break;
	case 38:
#line 350 "../../../src/angel/angel_config_parser.rl"
	{ ctx->number2 = ctx->number; }
	break;
	case 4:
#line 86 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, tokenstart, p - tokenstart);
		tokenstart = NULL;
		ctx->readingtoken = FALSE;
	}
#line 98 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->itemname = ctx->token;
		ctx->token = g_string_sized_new(0);
		ctx->itemvalue = li_value_new_hash();
	}
	break;
	case 12:
#line 86 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, tokenstart, p - tokenstart);
		tokenstart = NULL;
		ctx->readingtoken = FALSE;
	}
#line 279 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_string(ctx->token));
		ctx->token = g_string_sized_new(0);
		ctx->curvalue= NULL;
	}
	break;
	case 37:
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
#line 209 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_number(ctx->number);
	}
	break;
	case 9:
#line 124 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected identifier", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 3:
#line 130 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected block ('{...}' or ';') for item '%s'", format_char(ctx, (*p)), ctx->itemname->str);
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 27:
#line 148 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ';'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 74:
#line 154 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ':'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 34:
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 75:
#line 178 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ']'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 52:
#line 184 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ')'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 48:
#line 201 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(TRUE);
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 65:
#line 201 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(TRUE);
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
	break;
	case 89:
#line 201 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(TRUE);
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 49:
#line 201 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(TRUE);
	}
#line 284 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (!ctx->curvalue) ctx->curvalue = li_value_new_none();
		if (NULL != g_hash_table_lookup(ctx->itemvalue->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(ctx->itemvalue->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 45:
#line 205 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(FALSE);
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 62:
#line 205 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(FALSE);
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
	break;
	case 86:
#line 205 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(FALSE);
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 46:
#line 205 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(FALSE);
	}
#line 284 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (!ctx->curvalue) ctx->curvalue = li_value_new_none();
		if (NULL != g_hash_table_lookup(ctx->itemvalue->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(ctx->itemvalue->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 56:
#line 209 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_number(ctx->number);
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
	break;
	case 79:
#line 209 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_number(ctx->number);
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 39:
#line 209 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_number(ctx->number);
	}
#line 284 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (!ctx->curvalue) ctx->curvalue = li_value_new_none();
		if (NULL != g_hash_table_lookup(ctx->itemvalue->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(ctx->itemvalue->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 42:
#line 213 "../../../src/angel/angel_config_parser.rl"
	{
		liValueRange vr = { ctx->number2, ctx->number };
		ctx->curvalue = li_value_new_range(vr);
		if (ctx->number2 > ctx->number) {
			GString *tmp = li_value_to_string(ctx->curvalue);
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("range broken: %s (from > to)", tmp->str);
			g_string_free(tmp, TRUE);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 59:
#line 213 "../../../src/angel/angel_config_parser.rl"
	{
		liValueRange vr = { ctx->number2, ctx->number };
		ctx->curvalue = li_value_new_range(vr);
		if (ctx->number2 > ctx->number) {
			GString *tmp = li_value_to_string(ctx->curvalue);
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("range broken: %s (from > to)", tmp->str);
			g_string_free(tmp, TRUE);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
	break;
	case 83:
#line 213 "../../../src/angel/angel_config_parser.rl"
	{
		liValueRange vr = { ctx->number2, ctx->number };
		ctx->curvalue = li_value_new_range(vr);
		if (ctx->number2 > ctx->number) {
			GString *tmp = li_value_to_string(ctx->curvalue);
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("range broken: %s (from > to)", tmp->str);
			g_string_free(tmp, TRUE);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 43:
#line 213 "../../../src/angel/angel_config_parser.rl"
	{
		liValueRange vr = { ctx->number2, ctx->number };
		ctx->curvalue = li_value_new_range(vr);
		if (ctx->number2 > ctx->number) {
			GString *tmp = li_value_to_string(ctx->curvalue);
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("range broken: %s (from > to)", tmp->str);
			g_string_free(tmp, TRUE);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
	}
#line 284 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (!ctx->curvalue) ctx->curvalue = li_value_new_none();
		if (NULL != g_hash_table_lookup(ctx->itemvalue->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(ctx->itemvalue->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 54:
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 55:
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 240 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 73:
#line 252 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 77:
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 78:
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
#line 272 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 8:
#line 303 "../../../src/angel/angel_config_parser.rl"
	{ fctx->line--; }
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 21:
#line 347 "../../../src/angel/angel_config_parser.rl"
	{ ctx->number = 0; ctx->negate = FALSE; }
#line 330 "../../../src/angel/angel_config_parser.rl"
	{
		if (ctx->negate) {
			if ((G_MININT64 + ((*p) - '0')) / 10 > ctx->number) {
				UPDATE_COLUMN();
				PARSE_ERROR("Integer underflow");
				ctx->cs = angel_config_parser_error; {p++; goto _out; }
			}
			ctx->number = ctx->number*10 - ((*p) - '0');
		} else {
			if ((G_MAXINT64 - ((*p) - '0')) / 10 < ctx->number) {
				UPDATE_COLUMN();
				PARSE_ERROR("Integer overflow");
				ctx->cs = angel_config_parser_error; {p++; goto _out; }
			}
			ctx->number = ctx->number*10 + ((*p) - '0');
		}
	}
	break;
	case 20:
#line 347 "../../../src/angel/angel_config_parser.rl"
	{ ctx->number = 0; ctx->negate = FALSE; }
#line 347 "../../../src/angel/angel_config_parser.rl"
	{ctx->negate = TRUE;}
	break;
	case 5:
#line 86 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, tokenstart, p - tokenstart);
		tokenstart = NULL;
		ctx->readingtoken = FALSE;
	}
#line 98 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->itemname = ctx->token;
		ctx->token = g_string_sized_new(0);
		ctx->itemvalue = li_value_new_hash();
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 6:
#line 86 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, tokenstart, p - tokenstart);
		tokenstart = NULL;
		ctx->readingtoken = FALSE;
	}
#line 98 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->itemname = ctx->token;
		ctx->token = g_string_sized_new(0);
		ctx->itemvalue = li_value_new_hash();
	}
#line 104 "../../../src/angel/angel_config_parser.rl"
	{
		li_plugins_handle_item(srv, ctx->itemname, ctx->itemvalue);
		g_string_free(ctx->itemname, TRUE);
		ctx->itemname = NULL;
		li_value_free(ctx->itemvalue);
		ctx->itemvalue = NULL;
	}
	break;
	case 13:
#line 86 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, tokenstart, p - tokenstart);
		tokenstart = NULL;
		ctx->readingtoken = FALSE;
	}
#line 279 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_string(ctx->token));
		ctx->token = g_string_sized_new(0);
		ctx->curvalue= NULL;
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 14:
#line 86 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, tokenstart, p - tokenstart);
		tokenstart = NULL;
		ctx->readingtoken = FALSE;
	}
#line 279 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_string(ctx->token));
		ctx->token = g_string_sized_new(0);
		ctx->curvalue= NULL;
	}
#line 192 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_truncate(ctx->token, 0);
	}
	break;
	case 15:
#line 86 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, tokenstart, p - tokenstart);
		tokenstart = NULL;
		ctx->readingtoken = FALSE;
	}
#line 279 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_string(ctx->token));
		ctx->token = g_string_sized_new(0);
		ctx->curvalue= NULL;
	}
#line 230 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_list());
		ctx->curvalue = NULL;
		{ update_stack(ctx); { ctx->stack[ ctx->top++] =  ctx->cs;  ctx->cs = 52; goto _again;}}
	}
	break;
	case 17:
#line 86 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, tokenstart, p - tokenstart);
		tokenstart = NULL;
		ctx->readingtoken = FALSE;
	}
#line 279 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_string(ctx->token));
		ctx->token = g_string_sized_new(0);
		ctx->curvalue= NULL;
	}
#line 247 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_hash());
		ctx->curvalue = NULL;
		{ update_stack(ctx); { ctx->stack[ ctx->top++] =  ctx->cs;  ctx->cs = 95; goto _again;}}
	}
	break;
	case 16:
#line 86 "../../../src/angel/angel_config_parser.rl"
	{
		g_string_append_len(ctx->token, tokenstart, p - tokenstart);
		tokenstart = NULL;
		ctx->readingtoken = FALSE;
	}
#line 279 "../../../src/angel/angel_config_parser.rl"
	{
		g_ptr_array_add(ctx->valuestack, li_value_new_string(ctx->token));
		ctx->token = g_string_sized_new(0);
		ctx->curvalue= NULL;
	}
#line 284 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (!ctx->curvalue) ctx->curvalue = li_value_new_none();
		if (NULL != g_hash_table_lookup(ctx->itemvalue->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(ctx->itemvalue->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 57:
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
#line 209 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_number(ctx->number);
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
	break;
	case 80:
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
#line 209 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_number(ctx->number);
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
	break;
	case 70:
#line 142 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("forbidden character '%s' in string", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 160 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a string (\"...\")", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 24:
#line 142 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("forbidden character '%s' in string", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 71:
#line 160 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a string (\"...\")", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 154 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ':'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 68:
#line 160 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a string (\"...\")", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 178 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ']'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 40:
#line 166 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a number", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 11:
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 148 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ';'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 50:
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 184 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ')'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 66:
#line 201 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(TRUE);
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 67:
#line 201 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(TRUE);
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 240 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 90:
#line 201 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(TRUE);
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 91:
#line 201 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(TRUE);
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
#line 272 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 63:
#line 205 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(FALSE);
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 64:
#line 205 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(FALSE);
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 240 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 87:
#line 205 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(FALSE);
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 88:
#line 205 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_bool(FALSE);
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
#line 272 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 58:
#line 209 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_number(ctx->number);
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 240 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 81:
#line 209 "../../../src/angel/angel_config_parser.rl"
	{
		ctx->curvalue = li_value_new_number(ctx->number);
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
#line 272 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 60:
#line 213 "../../../src/angel/angel_config_parser.rl"
	{
		liValueRange vr = { ctx->number2, ctx->number };
		ctx->curvalue = li_value_new_range(vr);
		if (ctx->number2 > ctx->number) {
			GString *tmp = li_value_to_string(ctx->curvalue);
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("range broken: %s (from > to)", tmp->str);
			g_string_free(tmp, TRUE);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 61:
#line 213 "../../../src/angel/angel_config_parser.rl"
	{
		liValueRange vr = { ctx->number2, ctx->number };
		ctx->curvalue = li_value_new_range(vr);
		if (ctx->number2 > ctx->number) {
			GString *tmp = li_value_to_string(ctx->curvalue);
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("range broken: %s (from > to)", tmp->str);
			g_string_free(tmp, TRUE);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
	}
#line 235 "../../../src/angel/angel_config_parser.rl"
	{
		liValue *vlist = g_ptr_array_index(ctx->valuestack, ctx->valuestack->len-1);
		g_ptr_array_add(vlist->data.list, ctx->curvalue);
		ctx->curvalue = NULL;
	}
#line 240 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 84:
#line 213 "../../../src/angel/angel_config_parser.rl"
	{
		liValueRange vr = { ctx->number2, ctx->number };
		ctx->curvalue = li_value_new_range(vr);
		if (ctx->number2 > ctx->number) {
			GString *tmp = li_value_to_string(ctx->curvalue);
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("range broken: %s (from > to)", tmp->str);
			g_string_free(tmp, TRUE);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
#line 92 "../../../src/angel/angel_config_parser.rl"
	{
		fctx->line++;
		fctx->column = 1;
		linestart = p+1;
	}
	break;
	case 85:
#line 213 "../../../src/angel/angel_config_parser.rl"
	{
		liValueRange vr = { ctx->number2, ctx->number };
		ctx->curvalue = li_value_new_range(vr);
		if (ctx->number2 > ctx->number) {
			GString *tmp = li_value_to_string(ctx->curvalue);
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("range broken: %s (from > to)", tmp->str);
			g_string_free(tmp, TRUE);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
	}
#line 256 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len-1;
		liValue *vname = g_ptr_array_index(ctx->valuestack, ndx);
		liValue *vhash = g_ptr_array_index(ctx->valuestack, ndx-1);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		if (NULL != g_hash_table_lookup(vhash->data.hash, vname->data.string)) {
			UPDATE_COLUMN();
			PARSE_ERROR_FMT("duplicate key '%s' in item '%s'", vname->data.string->str, ctx->itemname->str);
			li_value_free(vname);
			ctx->cs = angel_config_parser_error; {p++; goto _out; }
		}
		g_hash_table_insert(vhash->data.hash, vname->data.string, ctx->curvalue);
		ctx->curvalue = NULL;
		vname->type = LI_VALUE_NONE;
		li_value_free(vname);
	}
#line 272 "../../../src/angel/angel_config_parser.rl"
	{
		guint ndx = ctx->valuestack->len - 1;
		ctx->curvalue = g_ptr_array_index(ctx->valuestack, ndx);
		g_ptr_array_set_size(ctx->valuestack, ndx);
		{ ctx->cs =  ctx->stack[-- ctx->top]; { update_stack(ctx); }goto _again;}
	}
	break;
	case 92:
#line 136 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected hexdigit", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 142 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("forbidden character '%s' in string", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 160 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a string (\"...\")", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 31:
#line 136 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected hexdigit", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 142 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("forbidden character '%s' in string", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
#line 2198 "angel_config_parser.c"
	}

_again:
	if (  ctx->cs == 0 )
		goto _out;
	if ( ++p != pe )
		goto _resume;
	_test_eof: {}
	if ( p == eof )
	{
	switch ( _angel_config_parser_eof_actions[ ctx->cs] ) {
	case 1:
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 9:
#line 124 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected identifier", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 3:
#line 130 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected block ('{...}' or ';') for item '%s'", format_char(ctx, (*p)), ctx->itemname->str);
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 27:
#line 148 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ';'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 74:
#line 154 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ':'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 34:
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 75:
#line 178 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ']'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 52:
#line 184 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ')'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 70:
#line 142 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("forbidden character '%s' in string", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 160 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a string (\"...\")", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 24:
#line 142 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("forbidden character '%s' in string", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 71:
#line 160 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a string (\"...\")", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 154 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ':'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 68:
#line 160 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a string (\"...\")", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 178 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ']'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 40:
#line 166 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a number", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 11:
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 148 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ';'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 82:
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 178 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ']'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 50:
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 184 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected ')'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 92:
#line 136 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected hexdigit", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 142 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("forbidden character '%s' in string", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 160 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a string (\"...\")", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
	case 31:
#line 136 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected hexdigit", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 142 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("forbidden character '%s' in string", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 172 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s', expected a value", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
#line 118 "../../../src/angel/angel_config_parser.rl"
	{
		UPDATE_COLUMN();
		PARSE_ERROR_FMT("unexpected character '%s'", format_char(ctx, (*p)));
		ctx->cs = angel_config_parser_error; {p++; goto _out; }
	}
	break;
#line 2528 "angel_config_parser.c"
	}
	}

	_out: {}
	}

#line 429 "../../../src/angel/angel_config_parser.rl"

	if (ctx->readingtoken) g_string_append_len(ctx->token, tokenstart, p - tokenstart);

	UPDATE_COLUMN();
	fctx->column--;

	if (err && *err) return FALSE;

	if (angel_config_parser_has_error(ctx)) {
		PARSE_ERROR("unknown parser error");
		return FALSE;
	}

	return TRUE;
}

gboolean li_angel_config_parse_file(liServer *srv, const gchar *filename, GError **err) {
	char *data = NULL;
	gsize len = 0;
	filecontext sfctx, *fctx = &sfctx;
	pcontext *ctx = angel_config_parser_new();

	if (err && *err) goto error;

	if (!g_file_get_contents(filename, &data, &len, err)) goto error;

	sfctx.filename = filename;
	sfctx.line = 1;
	sfctx.column = 1;
	if (!angel_config_parse_data(srv, ctx, fctx, data, len, err)) goto error;
	if (!angel_config_parser_finalize(ctx, fctx, err)) goto error;

	if (data) g_free(data);
	angel_config_parser_free(ctx);
	return TRUE;

error:
	if (data) g_free(data);
	angel_config_parser_free(ctx);
	return FALSE;
}
